macro_rules! check_op {
($helper:expr, $a:expr, $b:expr, $op:tt) => { ... };
}Expand description
A check macro variant that accepts any binary check operation while providing useful information TODO Example
macro_rules! check_op {
($helper:expr, $a:expr, $b:expr, $op:tt) => { ... };
}A check macro variant that accepts any binary check operation while providing useful information TODO Example